import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
var _excluded = ["chart", "chartRef", "data", "class", "style", "onReady"];
import isEmpty from 'lodash/isEmpty';
import isEqual from 'lodash/isEqual';
import { defineComponent, h } from 'vue-demi';
var BaseChart = defineComponent({
  inheritAttrs: false,
  name: 'BaseChart',
  computed: {
    attrConfig: function attrConfig() {
      return _objectSpread({}, this.$attrs);
    },
    chartData: function chartData() {
      var data = this.attrConfig.data;
      return data || [];
    },
    chartConfig: function chartConfig() {
      var _this$attrConfig = this.attrConfig,
        chart = _this$attrConfig.chart,
        chartRef = _this$attrConfig.chartRef,
        data = _this$attrConfig.data,
        className = _this$attrConfig.class,
        style = _this$attrConfig.style,
        onReady = _this$attrConfig.onReady,
        config = _objectWithoutProperties(_this$attrConfig, _excluded);
      return config;
    }
  },
  mounted: function mounted() {
    var chartRef = this.$attrs.chartRef;
    var _this$attrConfig2 = this.attrConfig,
      Chart = _this$attrConfig2.chart,
      onReady = _this$attrConfig2.onReady;
    var plot = new Chart(this.$el, _objectSpread({
      data: this.chartData
    }, this.chartConfig));
    plot.render();
    if (chartRef) {
      chartRef.value = plot;
    }
    this.plot = plot;
    onReady === null || onReady === void 0 || onReady(plot);
  },
  beforeUnmount: function beforeUnmount() {
    /* istanbul ignore else */
    if (this.plot) {
      this.plot.destroy();
    }
  },
  watch: {
    chartData: function chartData(data, oldData) {
      /* istanbul ignore else */
      if (this.plot) {
        if (isEmpty(oldData)) {
          this.plot.update(_objectSpread({
            data: data
          }, this.chartConfig));
          this.plot.render();
        } else {
          this.plot.changeData(data);
        }
      }
    },
    chartConfig: function chartConfig(config, oldConfig) {
      /* istanbul ignore else */
      if (this.plot) {
        if (!isEqual(config, oldConfig)) {
          this.plot.update(_objectSpread({
            data: this.chartData
          }, config));
        }
      }
    }
  },
  render: function render() {
    return h("div", {
      "class": this.attrConfig.class,
      "style": this.attrConfig.style
    });
  }
});
export default BaseChart;